@@ -2,8 +2,8 @@ use clap::Parser;
 
 #[derive(Parser, Debug)]
 pub struct CLI {
-    #[clap(short, long)]
+    // #[clap(short, long, default_value = "search")]
     pub project_name: String,
-    #[clap(short, long, default_value = "build")]
+    #[clap(short, long, default_value = "run")]
     pub subcommand: String,
 }
